(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     32297,        675]
NotebookOptionsPosition[     31772,        654]
NotebookOutlinePosition[     32151,        670]
CellTagsIndexPosition[     32108,        667]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Example Organism-namespace Cambium model, and \
conversion of this model into an Organism model file.  \n\nThe generated \
Organism model file is written to L1Clawus-autotrans.model .\nSee also: \
L1Clawus.model - original model by Henrik J\[ODoubleDot]nsson (included in \
the containing directory)",
 FontSize->14]], "Text",
 CellChangeTimes->{{3.4601369649309998`*^9, 3.4601371225690002`*^9}, {
   3.460137192552*^9, 3.46013736488*^9}, {3.4602328925863633`*^9, 
   3.4602328945673633`*^9}, {3.492178880174366*^9, 3.4921789734537015`*^9}, {
   3.4921790099817905`*^9, 3.49217916941391*^9}, {3.492179240293964*^9, 
   3.4921792830774107`*^9}, {3.492179326557898*^9, 3.4921793575176687`*^9}, {
   3.492179399613076*^9, 3.4921794440946207`*^9}, {3.492179498213716*^9, 
   3.4921796381817217`*^9}, {3.4921796847663865`*^9, 3.492179806989377*^9}, {
   3.492179847446691*^9, 3.4921798957514544`*^9}, {3.4921799550298443`*^9, 
   3.492180018405469*^9}, {3.492180391959835*^9, 3.492180504413267*^9}, {
   3.49218063558277*^9, 3.492180639806011*^9}, {3.492180709005969*^9, 
   3.492180733861391*^9}, {3.4921808095827217`*^9, 3.492180817126154*^9}, {
   3.492180859061552*^9, 3.4921808750214653`*^9}, {3.4921809080053515`*^9, 
   3.4921809736781077`*^9}, {3.4921810446621675`*^9, 
   3.4921811113739834`*^9}, {3.492181209792613*^9, 3.4921813179347982`*^9}, {
   3.4921997593502517`*^9, 3.49219980302975*^9}, {3.4922028968137045`*^9, 
   3.4922029027260427`*^9}, {3.4922032486698294`*^9, 3.492203251037965*^9}, 
   3.4922033363268433`*^9, {3.4922035208943996`*^9, 3.4922035784296904`*^9}, {
   3.492203999110752*^9, 3.492204065767565*^9}, {3.4922644464059496`*^9, 
   3.4922644606367636`*^9}},
 Background->GrayLevel[0.85]],

Cell[BoxData[
 RowBox[{"Get", "[", 
  RowBox[{
   RowBox[{"NotebookDirectory", "[", "]"}], " ", "<>", " ", 
   "\"\<CambiumToOrganismTranslator.m\>\""}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"L1ClawusModel", " ", "=", " ", 
    RowBox[{"CambiumArrow", "[", 
     RowBox[{
      RowBox[{"Organism", "[", "composite", "]"}], ",", " ", 
      RowBox[{"{", "}"}], ",", " ", 
      RowBox[{"{", "}"}], ",", " ", 
      RowBox[{"{", "}"}], ",", " ", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ModelName", "[", "\"\<activatorGrn\>\"", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"TopologyName", "[", "\"\<topologyTmp\>\"", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"TopologyVariables", "[", 
         RowBox[{
         "\"\<x\>\"", ",", " ", "\"\<y\>\"", ",", " ", "\"\<size\>\""}], 
         "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"SpeciesVariables", "[", 
         RowBox[{
         "\"\<L1helper\>\"", ",", " ", "\"\<L1\>\"", ",", " ", 
          "\"\<L1signal\>\"", ",", " ", "\"\<stemMarker\>\"", ",", " ", 
          "\"\<stemSignal\>\"", ",", " ", "\"\<brusselatorX\>\"", ",", " ", 
          "\"\<brusselatorY\>\"", ",", " ", "\"\<WUS\>\"", ",", " ", 
          "\"\<WUSsignal\>\"", ",", " ", "\"\<CLV1\>\"", ",", " ", 
          "\"\<CLV3\>\"", ",", " ", "\"\<apical\>\"", ",", " ", 
          "\"\<apicalSignal\>\""}], "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Reactions", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "topologyReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Identifier", "[", "\"\<growthExponential\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", "0.0001", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "topologyReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Identifier", "[", "\"\<springAsymmetric\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"0.8", ",", " ", "0.1", ",", " ", "0.3"}], "]"}], ",", 
              " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "topologyReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Identifier", "[", "\"\<sphereCylinderWall\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"0.1", ",", " ", "9.0"}], "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "compartmentChange", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "Identifier", "[", "\"\<divisionRandomDirectionSphere\>\"", 
               "]"}], ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"0.9", ",", " ", "0.1", ",", " ", "0.3"}], "]"}], ",", 
              " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "compartmentChange", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Identifier", "[", "\"\<removalThreshold\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{
                RowBox[{"-", "3.0"}], ",", " ", 
                RowBox[{"-", "1"}]}], "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<y\>\"", "}"}], "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<L1\>\"", "]"}], ",", " ", 
              RowBox[{
              "Identifier", "[", "\"\<creationSpatialSphereCylinder\>\"", 
               "]"}], ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"0.01", ",", " ", "8.5", ",", " ", "1"}], "]"}], ",", 
              " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<L1\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.01", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<L1signal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<creationOne\>\"", "]"}], ",", 
              " ", 
              RowBox[{"Parameters", "[", "0.2", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<L1\>\"", "}"}], "]"}]}], "}"}]}], "]"}], ",",
           "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<L1signal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<L1signal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<diffusionSimple\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<stemMarker\>\"", "]"}], ",", " ", 
              RowBox[{
              "Identifier", "[", "\"\<creationSpatialThreshold\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"0.001", ",", " ", 
                RowBox[{"-", "1.0"}], ",", " ", 
                RowBox[{"-", "1"}]}], "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<y\>\"", "}"}], "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<stemMarker\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.001", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<stemSignal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<creationOne\>\"", "]"}], ",", 
              " ", 
              RowBox[{"Parameters", "[", "0.2", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<stemMarker\>\"", "}"}], "]"}]}], "}"}]}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<stemSignal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<stemSignal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<diffusionSimple\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorX\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<creationZero\>\"", "]"}], ",", 
              " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorX\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.3", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorX\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationTwo\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.01", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<L1signal\>\"", "}"}], "]"}]}], "}"}]}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorX\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationTwo\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.01", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<stemSignal\>\"", "}"}], "]"}]}], "}"}]}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorX\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<diffusionSimple\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorY\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<creationOne\>\"", "]"}], ",", 
              " ", 
              RowBox[{"Parameters", "[", "0.2", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<brusselatorX\>\"", "}"}], "]"}]}], "}"}]}], 
           "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<brusselatorY\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<diffusionSimple\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", "1.5", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<WUS\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<grn\>\"", "]"}], ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"0.0", ",", " ", "10.0", ",", " ", "0.2", ",", " ", 
                RowBox[{"-", "10.0"}], ",", " ", 
                RowBox[{"-", "20.0"}]}], "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", 
                RowBox[{
                "\"\<brusselatorX\>\"", ",", " ", "\"\<L1signal\>\"", ",", 
                 " ", "\"\<stemSignal\>\""}], "}"}], "]"}]}], "}"}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<WUS\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<WUSsignal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<creationOne\>\"", "]"}], ",", 
              " ", 
              RowBox[{"Parameters", "[", "0.05", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", "\"\<WUS\>\"", "}"}], "]"}]}], "}"}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<WUSsignal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.05", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<WUSsignal\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<diffusionSimple\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<CLV1\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<gsrn\>\"", "]"}], ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{
                RowBox[{"-", "10.0"}], ",", " ", "10.0", ",", " ", "10.0", 
                ",", " ", "10.0"}], "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{
                RowBox[{"{", "\"\<WUS\>\"", "}"}], ",", " ", 
                RowBox[{"{", "\"\<WUS\>\"", "}"}]}], "]"}]}], "}"}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<CLV1\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<CLV3\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<grn\>\"", "]"}], ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{
                RowBox[{"-", "3.5"}], ",", " ", "10.0", ",", " ", "1.0", ",", 
                " ", "7", ",", " ", 
                RowBox[{"-", "20"}], ",", " ", 
                RowBox[{"-", "20"}]}], "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{"{", 
                RowBox[{
                "\"\<L1signal\>\"", ",", " ", "\"\<WUSsignal\>\"", ",", " ", 
                 "\"\<WUS\>\"", ",", " ", "\"\<stemSignal\>\""}], "}"}], 
               "]"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "speciesReaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Species", "[", "\"\<CLV3\>\"", "]"}], ",", " ", 
              RowBox[{"Identifier", "[", "\"\<degradationOne\>\"", "]"}], ",",
               " ", 
              RowBox[{"Parameters", "[", "0.05", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "reaction", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Identifier", "[", "\"\<massActionEnzymatic\>\"", "]"}],
               ",", " ", 
              RowBox[{"Parameters", "[", "0.1", "]"}], ",", " ", 
              RowBox[{"LinkedVariables", "[", 
               RowBox[{
                RowBox[{"{", "\"\<brusselatorY\>\"", "}"}], ",", " ", 
                RowBox[{"{", "\"\<brusselatorX\>\"", "}"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<brusselatorX\>\"", ",", " ", "\"\<brusselatorX\>\""}], 
                 "}"}]}], "]"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]",
           "\[IndentingNewLine]", 
          RowBox[{"CambiumArrow", "[", 
           RowBox[{
            RowBox[{"Organism", "[", "neighborhoodRule", "]"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "Identifier", "[", "\"\<neighborhoodDistanceSphere\>\"", "]"}], 
              ",", " ", 
              RowBox[{"Parameters", "[", 
               RowBox[{"1.0", ",", " ", "1", ",", " ", "0.0"}], "]"}], ",", 
              " ", 
              RowBox[{"LinkedVariables", "[", "]"}]}], "}"}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.4922612377384243`*^9, 3.4922614033638973`*^9}, {
  3.4922614545558257`*^9, 3.492261566215212*^9}, {3.4922616119898305`*^9, 
  3.49226182860422*^9}, {3.4922618594639854`*^9, 3.4922620004980516`*^9}, {
  3.4922620524330225`*^9, 3.4922620830507736`*^9}, {3.492262119793875*^9, 
  3.4922626532573876`*^9}, {3.4922626885334053`*^9, 3.492262891501014*^9}, {
  3.492263294348056*^9, 3.4922633024015164`*^9}, {3.4922636295712295`*^9, 
  3.492263631767355*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"L1ClawusTranslation", " ", "=", " ", 
  RowBox[{
  "L1ClawusModel", " ", "/.", " ", "TranslateCambiumToOrganism"}]}]], "Input",
 CellChangeTimes->{{3.492262953213544*^9, 3.492262963197115*^9}}],

Cell[BoxData["\<\"activatorGrn 1 13 1 1\\n\\ntopologyTmp 3 3 2\\t# x, y, size\
\\ngrowthExponential 1 0 \\n0.0001\\nspringAsymmetric 3 0 \\n0.8 0.1 \
0.3\\nsphereCylinderWall 2 0 \\n0.1 9.\\ndivisionRandomDirectionSphere 3 0 \
\\n0.9 0.1 0.3\\nremovalThreshold 2 1 1\\n-3. -1\\n1\\t # y\\n\\nL1helper 3 0\
\\n\\nL1 4 2\\ncreationSpatialSphereCylinder 3 0 \\n0.01 8.5 \
1\\ndegradationOne 1 0 \\n0.01\\n\\nL1signal 5 3\\ncreationOne 1 1 \
1\\n0.2\\n4\\t # L1\\ndegradationOne 1 0 \\n0.1\\ndiffusionSimple 1 0 \
\\n0.1\\n\\nstemMarker 6 2\\ncreationSpatialThreshold 3 1 1\\n0.001 -1. \
-1\\n1\\t # y\\ndegradationOne 1 0 \\n0.001\\n\\nstemSignal 7 3\\ncreationOne \
1 1 1\\n0.2\\n6\\t # stemMarker\\ndegradationOne 1 0 \\n0.1\\ndiffusionSimple \
1 0 \\n0.1\\n\\nbrusselatorX 8 5\\ncreationZero 1 0 \\n0.1\\ndegradationOne 1 \
0 \\n0.3\\ndegradationTwo 1 1 1\\n0.01\\n5\\t # L1signal\\ndegradationTwo 1 1 \
1\\n0.01\\n7\\t # stemSignal\\ndiffusionSimple 1 0 \\n0.1\\n\\nbrusselatorY 9 \
2\\ncreationOne 1 1 1\\n0.2\\n8\\t # brusselatorX\\ndiffusionSimple 1 0 \
\\n1.5\\n\\nWUS 10 2\\ngrn 5 1 3\\n0. 10. 0.2 -10. -20.\\n8 5 7\\t # \
brusselatorX, L1signal, stemSignal\\ndegradationOne 1 0 \\n0.1\\n\\nWUSsignal \
11 3\\ncreationOne 1 1 1\\n0.05\\n10\\t # WUS\\ndegradationOne 1 0 \
\\n0.05\\ndiffusionSimple 1 0 \\n0.1\\n\\nCLV1 12 2\\ngsrn 4 2 1 1\\n-10. 10. \
10. 10.\\n10\\t # WUS\\n10\\t # WUS\\ndegradationOne 1 0 \\n0.1\\n\\nCLV3 13 \
2\\ngrn 6 1 4\\n-3.5 10. 1. 7 -20 -20\\n5 11 10 7\\t # L1signal, WUSsignal, \
WUS, stemSignal\\ndegradationOne 1 0 \\n0.05\\n\\napical 14 \
0\\n\\napicalSignal 15 0\\n\\nmassActionEnzymatic 1 3 1 1 2\\n0.1\\n9\\t # \
brusselatorY\\n8\\t # brusselatorX\\n8 8\\t # brusselatorX, \
brusselatorX\\n\\nneighborhoodDistanceSphere 3 0 \\n1. 1 0.\\n\"\>"], "Output",
 CellChangeTimes->{3.4922629787320037`*^9, 3.4922634144599257`*^9, 
  3.492264081604084*^9, 3.492264922858201*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fstr", " ", "=", " ", 
   RowBox[{"OpenWrite", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], " ", "<>", " ", 
     "\"\<L1Clawus-autotrans.model\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Write", "[", 
   RowBox[{"fstr", ",", " ", 
    RowBox[{"OutputForm", "[", "L1ClawusTranslation", "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Close", "[", "fstr", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.492263057029482*^9, 3.4922630672370653`*^9}}]
},
WindowSize->{624, 722},
WindowMargins->{{Automatic, 0}, {0, Automatic}},
Magnification->1.0000001192092896`,
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1738, 25, 142, "Text"],
Cell[2286, 47, 170, 4, 31, "Input"],
Cell[2459, 53, 26585, 546, 2592, "Input"],
Cell[CellGroupData[{
Cell[29069, 603, 217, 4, 31, "Input"],
Cell[29289, 609, 1910, 25, 2159, "Output"]
}, Open  ]],
Cell[31214, 637, 554, 15, 72, "Input"]
}
]
*)

(* End of internal cache information *)
